@@ -10,11 +10,11 @@ class MachineOperationMode(Enum):
     AIR = 3
     HOTPLUS = 258
 
-
 class ZoneMode(Enum):
-    COMFORT = 0
-    ECO = 1
-    STANDBY = 2
+    MANUAL = 0
+    MANUAL_SLEEP = 1
+    AUTOMATIC = 2
+    AUTOMATIC_SLEEP = 3
 
 class FancoilSpeed(Enum):
     AUTOMATIC = 0
@@ -81,6 +81,26 @@ def bit_value(state, address, bit):
     temp = format(state[address], '016b')
     return int(temp[len(temp)-1-bit])
 
+def change_range_bit_value(state, address, init_bit, num_bit, value):
+    if num_bit <= 0:
+        return state[address]
+    temp2 = list(format(state[address], '016b'))
+    idx = len(temp2)-init_bit-num_bit
+    idx2 = len(temp2)-init_bit
+    temp = list(format(value, '0'+str(num_bit)+ 'b'))
+    temp2[idx:idx2] = temp
+    return int("".join(temp2), 2)
+
+# def change_range_bit_value2(old_value, init_bit, num_bit, value):
+#     temp2 = list(old_value)
+#     idx = len(temp2)-init_bit-num_bit
+#     idx2 = len(temp2)-init_bit
+#     temp = list(format(value, '0'+str(num_bit)+ 'b'))
+#     temp2[idx:idx2] = temp
+#     return int("".join(temp2), 2)
+
+
+
 def change_bit_value(state, address, bit, value):
     if value:
         ch = '1'
